@@ -1,7 +1,6 @@
 package App::Netdisco::Web::Plugin::Search::Node;
 
 use Dancer ':syntax';
-use Dancer::Plugin::Ajax;
 use Dancer::Plugin::DBIC;
 use Dancer::Plugin::Auth::Extensible;
 
@@ -45,7 +44,7 @@ register_search_tab({
         description => 'Date Range in format "YYYY-MM-DD to YYYY-MM-DD"',
       },
       age_invert => {
-        description => 'Date Range is NOT within the supplied range',
+        description => 'Results should NOT be within daterange',
         type => 'boolean',
         default => 'false',
       },
@@ -59,7 +58,7 @@ register_search_tab({
 });
 
 # nodes matching the param as an IP or DNS hostname or MAC
-ajax '/ajax/content/search/node' => require_login sub {
+get '/ajax/content/search/node' => require_login sub {
     my $node = param('q');
     send_error('Missing node', 400) unless $node;
     content_type('text/html');
@@ -241,7 +240,7 @@ ajax '/ajax/content/search/node' => require_login sub {
     return unless $set and $set->has_rows;
     $set = $set->search_rs({}, { order_by => 'me.mac' });
 
-    template 'ajax/search/node_by_ip.tt', {
+    return template 'ajax/search/node_by_ip.tt', {
       macs => $set,
       archive_filter => {@active},
     };
