@@ -76,7 +76,7 @@ register 'register_worker' => sub {
 
       # per-device action but no device creds available
       return $job->add_status( Status->info('skip: driver or action not applicable') )
-        if 0 == scalar @newuserconf;
+        if 0 == scalar @newuserconf && $job->action ne "delete";
     }
 
     # back up and restore device_auth
